@@ -48,7 +48,7 @@ void __fastcall TForm1::BitBtn2Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TForm1::FormShow(TObject *Sender)
 {
-	ShellExecute(this->Handle, "open", "fourlaws.html", NULL, NULL, SW_SHOWMAXIMIZED);
+	ShellExecute(this->Handle, "open", "tract.html", NULL, NULL, SW_SHOWMAXIMIZED);
 }
 //---------------------------------------------------------------------------
 void __fastcall TForm1::BitBtn3Click(TObject *Sender)
