@@ -964,14 +964,40 @@ void __fastcall TForm1::FormShow(TObject *Sender)
 	DefaultStrKey->Persist(1);
 	*DefaultStrKey = "";
 
-	mainmgr = new BibleCSMGR(ModInstFrm);
+	try {
+		mainmgr = new BibleCSMGR(ModInstFrm);
+	}
+	catch (...) {
+		Application->Terminate();
+	}
 
+	if (!mainmgr->config)
+		Application->Terminate();
 	// Load devotion and show form
 
 	for (it = mainmgr->Modules.begin(); it != mainmgr->Modules.end(); it++) {
 		bool devotional = false;
 		bool glossary = false;
 
+		const char *check;
+		for (check = it->first.c_str(); *check; check++) {
+			if ((*check >= 'a') && (*check <= 'z'))
+				continue;
+			if ((*check >= 'A') && (*check <= 'Z'))
+				continue;
+			if ((*check >= '0') && (*check <= '9'))
+				continue;
+			if ((*check == ' ') || (*check == '_'))
+				continue;
+			break;
+		}
+		if (*check) {
+			char buf[2047];
+			sprintf(buf, "Module Name: (%s) is unsupported and the module must be upgraded or removed.  You may be able to merely modify the [name] line in the modules' .conf file located in the mods.d directory where you installed SWORD.  You should remove any special characters including spaces and symbols.  Send email to sword-support@crosswire.org if you need further assistance.", it->first.c_str());
+			MessageBox(this->Handle, buf, "Module Unsupported", MB_OK|MB_ICONWARNING);
+			continue;
+		}
+ 
 		// leave out enciphered texts with no key
 		if ((sit = mainmgr->config->Sections.find((*it).second->Name())) != mainmgr->config->Sections.end()) {
 			if ((eit = (*sit).second.find("CipherKey")) != (*sit).second.end()) {
