@@ -21,18 +21,16 @@ const AnsiString COLOR_EXT = ".sch";
 class TOptionsfrm : public TForm
 {
 __published:	// IDE-managed Components
-	TColorDialog *ColorDialog1;
+	TColorDialog *ColorDialogVS;
 	TPanel *Panel2;
-	TButton *Button1;
-	TButton *Button2;
 	TPageControl *PageControl1;
 	TTabSheet *TabSheet1;
 	TTabSheet *TabSheet2;
 	TPanel *Panel1;
-	TGroupBox *GroupBox1;
+	TGroupBox *gbPersonalize;
 	TCheckBox *AutoBMPersonal;
 	TCheckBox *AutoBMOther;
-	TGroupBox *GroupBox3;
+	TGroupBox *gbDefModules;
 	TComboBox *hebrewDefCB;
 	TComboBox *greekDefCB;
 	TComboBox *greekParseCB;
@@ -41,7 +39,7 @@ __published:	// IDE-managed Components
 	TLabel *Label6;
 	TLabel *Label7;
 	TLabel *Label8;
-	TGroupBox *GroupBox4;
+	TGroupBox *gbDevos;
 	TLabel *Label9;
 	TComboBox *dailyDefaultCB;
 	TCheckBox *devSplashCB;
@@ -49,12 +47,11 @@ __published:	// IDE-managed Components
 	TLabel *Label10;
 	TComboBox *strongsNumsCB;
 	TTabSheet *TabSheet3;
-	TLabel *Label1;
 	TCheckBox *HintPopups;
 	TLabel *Label4;
 	TComboBox *localeCB;
 	TPanel *Panel3;
-	TGroupBox *GroupBox5;
+	TGroupBox *gbColors;
 	TLabel *Label2;
 	TLabel *Label3;
 	TRichEdit *RTFPreview;
@@ -65,7 +62,7 @@ __published:	// IDE-managed Components
 	TButton *btnNumClr;
 	TLabel *Label11;
 	TLabel *Label13;
-	TShape *CurrentVSColor;
+	TShape *shpCurrVSClr;
 	TLabel *Label14;
 	TComboBox *cmbSchemeSelect;
 	TButton *btnFieldClr;
@@ -81,13 +78,32 @@ __published:	// IDE-managed Components
 	TSaveDialog *SaveSchDlg;
 	TMenuItem *DeleteScheme1;
 	TCheckBox *AutoLayout;
-        TGroupBox *GroupBox2;
-        TCheckBox *glosAsDictsCB;
+	TGroupBox *gbGloss;
+		TCheckBox *glosAsDictsCB;
+	TButton *btnModFonts;
+	TLabel *Label1;
+	TBitBtn *OkBtn;
+	TBitBtn *CancelBtn;
+	TCheckBox *HintStrongs;
+	TLabel *Label12;
+	TLabel *Label16;
+	TShape *shpStrongClr;
+	TButton *btnStrongClr;
+	TShape *shpMorphClr;
+	TButton *btnMorphClr;
+	TShape *shpFieldClr;
+	TColorDialog *ColorDialogStrongs;
+	TColorDialog *ColorDialogMorph;
+	TShape *shpNumClr;
+	TCheckBox *HintWords;
+	TComboBox *genDictCB;
+	TLabel *Label17;
+	TCheckBox *HintVLists;
 	void __fastcall btnCurrVerseClick(TObject *Sender);
 	void __fastcall FormCreate(TObject *Sender);
 	void __fastcall FormShow(TObject *Sender);
 	void __fastcall btnFontClick(TObject *Sender);
-	void __fastcall CurrentVSColorMouseDown(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
+	void __fastcall shpCurrVSClrMouseDown(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
 	void __fastcall btnNumClrClick(TObject *Sender);
 	void __fastcall btnFieldClrClick(TObject *Sender);
 	void __fastcall cmbTextSelectChange(TObject *Sender);
@@ -97,16 +113,34 @@ __published:	// IDE-managed Components
 	void __fastcall ExportClick(TObject *Sender);
 	void __fastcall ImportClick(TObject *Sender);
 	void __fastcall DeleteClick(TObject *Sender);
-	
+	void __fastcall btnModFontsClick(TObject *Sender);
+	void __fastcall HintPopupsClick(TObject *Sender);
+	void __fastcall btnStrongClrClick(TObject *Sender);
+	void __fastcall btnMorphClrClick(TObject *Sender);
+	void __fastcall shpFieldClrMouseDown(TObject *Sender, TMouseButton Button,
+		  TShiftState Shift, int X, int Y);
+	void __fastcall shpStrongClrMouseDown(TObject *Sender,
+		  TMouseButton Button, TShiftState Shift, int X, int Y);
+	void __fastcall shpMorphClrMouseDown(TObject *Sender, TMouseButton Button,
+		  TShiftState Shift, int X, int Y);
+	void __fastcall shpNumClrMouseDown(TObject *Sender, TMouseButton Button,
+          TShiftState Shift, int X, int Y);
+
 private:	// User declarations
 	static const char *defaultLocaleName;
 	static const char *defaultLocaleDescription;
 	CopyFontDlg(TFontSelFrm* lhs, const TFontSelFrm* rhs);
 	void FindSchemeNames();
+	void GetCurrentScheme();
 public:
-     TFontSelFrm* FontDialogText;
-     TFontSelFrm* FontDialogComment;
-     TFontSelFrm* FontDialogLD;
+	 TFontSelFrm* FontDialogText;
+	 TFontSelFrm* FontDialogComment;
+	 TFontSelFrm* FontDialogLD;
+	 TFontSelFrm* FontDialogPopup;
+	 TFontSelFrm* FontDialogSearch;
+	void LoadDispSettings(SWConfig* config);
+	void LoadMiscSettings(SWConfig* config);
+	void extractSettings(SWConfig* config);
 	void UpdatePreview();
 public:		// User declarations
 	__fastcall TOptionsfrm(TComponent* Owner);
