@@ -73,7 +73,6 @@ USEUNIT("..\..\..\..\src\utilfuns\zlib\untgz.c");
 USEUNIT("..\..\..\..\src\modules\filters\unicodertf.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\gbfmorph.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\thmlolb.cpp");
-USEUNIT("..\..\..\..\src\utilfuns\roman.c");
 USEUNIT("..\..\..\..\src\modules\filters\gbfhtmlhref.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\latin1utf8.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\latin1utf16.cpp");
@@ -116,6 +115,7 @@ USEUNIT("..\..\..\..\src\modules\filters\gbfosis.cpp");
 USEUNIT("..\..\..\..\src\modules\filters\thmlosis.cpp");
 USEUNIT("..\..\..\..\src\mgr\installmgr.cpp");
 USEUNIT("..\..\..\..\src\utilfuns\ftpparse.c");
+USEUNIT("..\..\..\..\src\utilfuns\roman.cpp");
 //---------------------------------------------------------------------------
 #define Library
 
