@@ -19,6 +19,8 @@
 #include <NMHttp.hpp>
 #include <Psock.hpp>
 
+using namespace std;
+using namespace sword;
 
 class VersionInfo {
 	public:
