@@ -14,8 +14,19 @@
 #include <versekey.h>
 #include <swmgr.h>
 #include <markupfiltmgr.h>
-
+#ifndef NO_SWORD_NAMESPACE
+using namespace sword;
+#endif
+extern "C" {
 #include "flatapi.h"
+}
+
+typedef struct {
+	ModMap::iterator it;
+//	void *it;
+	ModMap::iterator end;
+//	void *end;
+} ModItType;
 
 
 //-----------------------------------------------------------------
