@@ -3,14 +3,17 @@
 
 #include <stdio.h>
 #include <vector>
+#include <defs.h>
+
+SWORD_NAMESPACE_START
 
-using std::vector;
 
 // move this include to cpp once struct ftpparse isn't exposed anymore
 extern "C" {
 #include <ftpparse.h>
 }
 
+
 // initialize/cleanup SYSTEMWIDE library with life of this static.
 class InstallMgr_init {
 public:
@@ -41,6 +44,8 @@ char FTPURLGetFile(void *session, const char *dest, const char *sourceurl, bool
 // own FTPFile class or something that contains things like file name,
 // size, type (dir, file, special).  Then change to vector of this class
 // instead of ftpparse
-vector<struct ftpparse> FTPURLGetDir(void *session, const char *dirurl, bool passive = true);
+std::vector<struct ftpparse> FTPURLGetDir(void *session, const char *dirurl, bool passive = true);
 
-#endif
\ No newline at end of file
+SWORD_NAMESPACE_END
+
+#endif
