@@ -3,14 +3,14 @@
 
 #include <map>
 
-using namespace std;
+SWORD_NAMESPACE_START
 
 // multmap that still lets you use [] to reference FIRST
 // entry of a key if multiples exist
 template <class Key, class T, class Compare>
-class multimapwithdefault : public multimap<Key, T, Compare> {
+class multimapwithdefault : public std::multimap<Key, T, Compare> {
 public:
-	typedef pair<const Key, T> value_type;
+	typedef std::pair<const Key, T> value_type;
 	T& getWithDefault(const Key& k, const T& defaultValue) {
 		if (find(k) == end()) {
 			insert(value_type(k, defaultValue));
@@ -25,8 +25,8 @@ public:
 		return (*(find(k))).second;
 	}
 	bool has(const Key& k, const T &val) const {
-		typename multimap<Key, T, Compare>::const_iterator start = lower_bound(k);
-		typename multimap<Key, T, Compare>::const_iterator end = upper_bound(k);
+		typename std::multimap<Key, T, Compare>::const_iterator start = lower_bound(k);
+		typename std::multimap<Key, T, Compare>::const_iterator end = upper_bound(k);
 		for (; start!=end; start++) {
 			if (start->second == val)
 				return true;
@@ -35,4 +35,5 @@ public:
 	}
 };
 
+SWORD_NAMESPACE_END
 #endif
