@@ -4,7 +4,7 @@
  *  				many filter will need and can use as a starting
  *  				point. 
  *
- * $Id: swbasicfilter.h,v 1.9 2002/06/06 21:08:47 scribe Exp $
+ * $Id: swbasicfilter.h,v 1.12 2002/10/01 22:04:58 dglassey Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,7 +29,8 @@
 
 #include <defs.h>
 #include <map>
-using namespace std;
+
+SWORD_NAMESPACE_START
 
 /** A filter providing commonly used functionality.
 * This filter has facilities for handling SGML/HTML/XML like tokens and
@@ -62,7 +63,7 @@ protected:
 	const SWModule *module;
 	const SWKey *key;
 	char *resultBuffer;
-	typedef map<string, string> DualStringMap;
+	typedef std::map<std::string, std::string> DualStringMap;
 	DualStringMap tokenSubMap;
 	DualStringMap escSubMap;
 
@@ -114,4 +115,5 @@ protected:
 	virtual bool handleEscapeString(char **buf, const char *escString, DualStringMap &userData);
 };
 
+SWORD_NAMESPACE_END
 #endif
