@@ -2,7 +2,7 @@
  *  swcom.h   - code for base class 'SWCom'.  SWCom is the basis for all
  *		 types of commentary modules
  *
- * $Id: swcom.h,v 1.10 2002/07/28 01:48:38 scribe Exp $
+ * $Id: swcom.h,v 1.12 2002/10/01 19:52:40 dglassey Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -28,6 +28,8 @@
 
 #include <defs.h>
 
+SWORD_NAMESPACE_START
+
   /** The basis for all commentary modules
   */
 class SWDLLEXPORT SWCom : public SWModule {
@@ -47,6 +49,10 @@ public:
 	virtual ~SWCom();
 	virtual SWKey *CreateKey() { return new VerseKey(); }
 
+	virtual long Index() const;
+	virtual long Index(long iindex);
+
+
 
 	// OPERATORS -----------------------------------------------------------------
 	
@@ -54,5 +60,5 @@ public:
 
 };
 
-
+SWORD_NAMESPACE_END
 #endif
