@@ -2,7 +2,7 @@
  *  swtext.h   - code for base class 'SWText'.  SWText is the basis for all
  *		 types of text modules
  *
- * $Id: swtext.h,v 1.11 2002/07/28 01:48:38 scribe Exp $
+ * $Id: swtext.h,v 1.13 2002/10/01 19:52:40 dglassey Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,6 +29,8 @@
 
 #include <defs.h>
 
+SWORD_NAMESPACE_START
+
 /** The basis for all text modules
  */
 class SWDLLEXPORT SWText : public SWModule {
@@ -50,6 +52,8 @@ public:
 	*/
 	virtual SWKey *CreateKey();
 
+	virtual long Index() const;
+	virtual long Index(long iindex);
 
 	// OPERATORS -----------------------------------------------------------------
 	
@@ -57,5 +61,6 @@ public:
 
 };
 
+SWORD_NAMESPACE_END
 
 #endif
