@@ -27,6 +27,7 @@
 #include <unicode/bidi.h>
 
 #include <defs.h>
+SWORD_NAMESPACE_START
 
   /** This Filter shows/hides reorders UTF-8 text according to Unicode BiDi
   */
@@ -41,5 +42,6 @@ class SWDLLEXPORT UTF8BiDiReorder : public SWFilter
   virtual char ProcessText (char *text, int maxlen, const SWKey * key, const SWModule * = 0);
 };
 
+SWORD_NAMESPACE_END
 #endif
 
