@@ -5,9 +5,15 @@
 #ifndef _MSC_VER
 #include <iostream>
 #endif
+#if defined(_ICU_) && !defined(_ICUSWORD_)
+#define _USTDIO_
+#include <unicode/ustdio.h>
+#include <unicode/ustream.h>
+#endif
 #include "swlog.h"
 //---------------------------------------------------------------------------
 
+SWORD_NAMESPACE_START
 
 SWLog *SWLog::systemlog = 0;
 
@@ -25,12 +31,20 @@ public:
 
 void SWLog::LogWarning(char *fmt, ...)
 {
+	#ifdef _USTDIO_
+	UChar msg[2048];
+	#else
 	char msg[2048];
+	#endif
 	va_list argptr;
 
 	if (logLevel >= 2) {
 		va_start(argptr, fmt);
+		#ifdef _USTDIO_
+		u_vsprintf(msg, NULL, fmt, argptr);
+		#else
 		vsprintf(msg, fmt, argptr);
+		#endif
 		va_end(argptr);
 
 #ifndef _MSC_VER
@@ -43,12 +57,20 @@ void SWLog::LogWarning(char *fmt, ...)
 
 void SWLog::LogError(char *fmt, ...)
 {
+	#ifdef _USTDIO_
+	UChar msg[2048];
+	#else
 	char msg[2048];
+	#endif
 	va_list argptr;
 
 	if (logLevel) {
 		va_start(argptr, fmt);
+		#ifdef _USTDIO_
+		u_vsprintf(msg, NULL, fmt, argptr);
+		#else
 		vsprintf(msg, fmt, argptr);
+		#endif
 		va_end(argptr);
 
 #ifndef _MSC_VER
@@ -61,12 +83,20 @@ void SWLog::LogError(char *fmt, ...)
 
 void SWLog::LogTimedInformation(char *fmt, ...)
 {
+	#ifdef _USTDIO_
+	UChar msg[2048];
+	#else
 	char msg[2048];
+	#endif
 	va_list argptr;
 
 	if (logLevel >= 4) {
 		va_start(argptr, fmt);
+		#ifdef _USTDIO_
+		u_vsprintf(msg, NULL, fmt, argptr);
+		#else
 		vsprintf(msg, fmt, argptr);
+		#endif
 		va_end(argptr);
 
 #ifndef _MSC_VER
@@ -79,12 +109,20 @@ void SWLog::LogTimedInformation(char *fmt, ...)
 
 void SWLog::LogInformation(char *fmt, ...)
 {
+	#ifdef _USTDIO_
+	UChar msg[2048];
+	#else
 	char msg[2048];
+	#endif
 	va_list argptr;
 
 	if (logLevel >= 3) {
 		va_start(argptr, fmt);
+		#ifdef _USTDIO_
+		u_vsprintf(msg, NULL, fmt, argptr);
+		#else
 		vsprintf(msg, fmt, argptr);
+		#endif
 		va_end(argptr);
 
 #ifndef _MSC_VER
@@ -92,4 +130,6 @@ void SWLog::LogInformation(char *fmt, ...)
 		std::cout << std::endl;
 #endif
 	}
-} 
+}
+
+SWORD_NAMESPACE_END
