@@ -10,6 +10,7 @@
 #include <string.h>
 #include <stdio.h>
 
+SWORD_NAMESPACE_START
 
 static const char *classes[] = {"StrKey", "SWKey", "SWObject", 0};
 SWClass StrKey::classdef(classes);
@@ -39,3 +40,5 @@ void StrKey::init() {
 
 StrKey::~StrKey() {
 }
+
+SWORD_NAMESPACE_END
