@@ -8,6 +8,8 @@
 #include <utilfuns.h>
 #include <string.h>
 
+SWORD_NAMESPACE_START
+
 static const char *classes[] = {"SWKey", "SWObject", 0};
 SWClass SWKey::classdef(classes);
 
@@ -36,7 +38,7 @@ SWKey::SWKey(SWKey const &k)
 	keytext   = 0;
 	rangeText = 0;
 	error     = k.error;
-	stdstr(&keytext, k.keytext);
+	setText(k.getText());
 	init();
 }
 
@@ -209,3 +211,5 @@ void SWKey::increment(int) {
 void SWKey::decrement(int) {
 	error = KEYERR_OUTOFBOUNDS;
 }
+
+SWORD_NAMESPACE_END
