@@ -1,7 +1,7 @@
 /******************************************************************************
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: treekeyidx.cpp,v 1.8 2002/09/11 07:04:20 scribe Exp $
+ * $Id: treekeyidx.cpp,v 1.13 2002/10/21 00:30:37 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -32,7 +32,8 @@
 #include <unistd.h>
 #endif
 
-using namespace std;
+SWORD_NAMESPACE_START
+
 static const char nl = '\n';
 static const char *classes[] = {"TreeKeyIdx", "TreeKey", "SWKey", "SWObject", 0};
 SWClass TreeKeyIdx::classdef(classes);
@@ -128,12 +129,12 @@ void TreeKeyIdx::save() {
 
 const char *TreeKeyIdx::getFullName() const {
 	TreeNode parent;
-	static string fullPath;
+	static std::string fullPath;
 	fullPath = currentNode.name;
 	parent.parent = currentNode.parent;
 	while (parent.parent > -1) {
 		getTreeNodeFromIdxOffset(parent.parent, &parent);
-		fullPath = ((string)parent.name) + (string) "/" + fullPath;
+		fullPath = ((std::string)parent.name) + (std::string) "/" + fullPath;
 	}
 	return fullPath.c_str();
 }
@@ -304,7 +305,7 @@ void TreeKeyIdx::getTreeNodeFromDatOffset(long ioffset, TreeNode *node) const {
 		read(datfd->getFd(), &tmp, 4);
 		node->firstChild = swordtoarch32(tmp);
 
-		string name;
+		std::string name;
 		do {
 			read(datfd->getFd(), &ch, 1);
 			name += ch;
@@ -336,27 +337,29 @@ void TreeKeyIdx::getTreeNodeFromDatOffset(long ioffset, TreeNode *node) const {
 
 char TreeKeyIdx::getTreeNodeFromIdxOffset(long ioffset, TreeNode *node) const {
 	__u32 offset;
-	char error = 0;
+	char error = KEYERR_OUTOFBOUNDS;
 	
 	if (ioffset < 0) {
 		ioffset = 0;
-		error = KEYERR_OUTOFBOUNDS;
+		error = 77;	// out of bounds but still position to 0;
 	}
 
 	node->offset = ioffset;
 	if (idxfd > 0) {
-		lseek(idxfd->getFd(), ioffset, SEEK_SET);
-		if (read(idxfd->getFd(), &offset, 4) == 4) {
-			offset = swordtoarch32(offset);
-			getTreeNodeFromDatOffset(offset, node);
-		}
-		else {
-			lseek(idxfd->getFd(), -4, SEEK_END);
+		if (idxfd->getFd() > 0) {
+			lseek(idxfd->getFd(), ioffset, SEEK_SET);
 			if (read(idxfd->getFd(), &offset, 4) == 4) {
 				offset = swordtoarch32(offset);
+				error = (error == 77) ? KEYERR_OUTOFBOUNDS : 0;
 				getTreeNodeFromDatOffset(offset, node);
 			}
-			error = KEYERR_OUTOFBOUNDS;
+			else {
+				lseek(idxfd->getFd(), -4, SEEK_END);
+				if (read(idxfd->getFd(), &offset, 4) == 4) {
+					offset = swordtoarch32(offset);
+					getTreeNodeFromDatOffset(offset, node);
+				}
+			}
 		}
 	}
 	return error;
@@ -595,3 +598,4 @@ SWKey *TreeKeyIdx::clone() const
 	return new TreeKeyIdx(*this);
 }
 
+SWORD_NAMESPACE_END
