@@ -19,6 +19,7 @@
 #include <rawverse.h>
 #include <rawcom.h>
 
+SWORD_NAMESPACE_START
 
  /******************************************************************************
  * RawCom Constructor - Initializes data for instance of RawCom
@@ -53,15 +54,7 @@ RawCom::~RawCom()
 char *RawCom::getRawEntry() {
 	long  start = 0;
 	unsigned short size = 0;
-	VerseKey *key = 0;
-
-	try {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	catch ( ... ) {}
-	if (!key)
-		key = new VerseKey(this->key);
-
+	VerseKey *key = &getVerseKey();
 
 	findoffset(key->Testament(), key->Index(), &start, &size);
 	entrySize = size;        // support getEntrySize call
@@ -79,14 +72,11 @@ char *RawCom::getRawEntry() {
      entrybuf[size] = 0;
 
 	rawFilter(entrybuf, size, 0);	// hack, decipher
-	rawFilter(entrybuf, size, key);
+	rawFilter(entrybuf, size*FILTERPAD, key);
 
         if (!isUnicode())
 		preptext(entrybuf);
 
-	if (key != this->key)
-		delete key;
-
 	return entrybuf;
 }
 
@@ -102,14 +92,7 @@ char *RawCom::getRawEntry() {
 void RawCom::increment(int steps) {
 	long  start;
 	unsigned short size;
-	VerseKey *tmpkey = 0;
-
-	try {
-		tmpkey = SWDYNAMIC_CAST(VerseKey, key);
-	}
-	catch ( ... ) {}
-	if (!tmpkey)
-		tmpkey = new VerseKey(key);
+	VerseKey *tmpkey = &getVerseKey();
 
 	findoffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
 
@@ -119,15 +102,7 @@ void RawCom::increment(int steps) {
 		unsigned short lastsize = size;
 		SWKey lasttry = *tmpkey;
 		(steps > 0) ? (*key)++ : (*key)--;
-		if (tmpkey != key)
-			delete tmpkey;
-		tmpkey = 0;
-		try {
-			tmpkey = SWDYNAMIC_CAST(VerseKey, key);
-		}
-		catch ( ... ) {}
-		if (!tmpkey)
-			tmpkey = new VerseKey(key);
+		tmpkey = &getVerseKey();
 
 		if ((error = key->Error())) {
 			*key = lastgood;
@@ -137,48 +112,26 @@ void RawCom::increment(int steps) {
 		findoffset(tmpkey->Testament(), index, &start, &size);
 		if (
 			(((laststart != start) || (lastsize != size))	// we're a different entry
-				&& (start > 0) && (size))	// and we actually have a size
+//				&& (start > 0)
+				&& (size))	// and we actually have a size
 				||(!skipConsecutiveLinks)) {	// or we don't want to skip consecutive links
 			steps += (steps < 0) ? 1 : -1;
 			lastgood = *tmpkey;
 		}
 	}
 	error = (error) ? KEYERR_OUTOFBOUNDS : 0;
-
-	if (tmpkey != key)
-		delete tmpkey;
 }
 
 
 void RawCom::setEntry(const char *inbuf, long len) {
-	VerseKey *key = 0;
-	// see if we have a VerseKey * or decendant
-	try {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	catch ( ... ) {}
-	// if we don't have a VerseKey * decendant, create our own
-	if (!key)
-		key = new VerseKey(this->key);
-
+	VerseKey *key = &getVerseKey();
 	settext(key->Testament(), key->Index(), inbuf, len);
-
-	if (this->key != key) // free our key if we created a VerseKey
-		delete key;
 }
 
 
 void RawCom::linkEntry(const SWKey *inkey) {
-	VerseKey *destkey = 0;
+	VerseKey *destkey = &getVerseKey();
 	const VerseKey *srckey = 0;
-	// see if we have a VerseKey * or decendant
-	try {
-		destkey = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	catch ( ... ) {}
-	// if we don't have a VerseKey * decendant, create our own
-	if (!destkey)
-		destkey = new VerseKey(this->key);
 
 	// see if we have a VerseKey * or decendant
 	try {
@@ -191,9 +144,6 @@ void RawCom::linkEntry(const SWKey *inkey) {
 
 	linkentry(destkey->Testament(), destkey->Index(), srckey->Index());
 
-	if (this->key != destkey) // free our key if we created a VerseKey
-		delete destkey;
-
 	if (inkey != srckey) // free our key if we created a VerseKey
 		delete srckey;
 }
@@ -207,17 +157,38 @@ void RawCom::linkEntry(const SWKey *inkey) {
 
 void RawCom::deleteEntry() {
 
-	VerseKey *key = 0;
+	VerseKey *key = &getVerseKey();
+	settext(key->Testament(), key->Index(), "");
+}
 
+
+VerseKey &RawCom::getVerseKey() {
+	static VerseKey tmpVK;
+	VerseKey *key;
+	// see if we have a VerseKey * or decendant
 	try {
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
 	}
-	catch ( ... ) {}
-	if (!key)
-		key = new VerseKey(this->key);
-
-	settext(key->Testament(), key->Index(), "");
-
-	if (key != this->key)
-		delete key;
+	catch ( ... ) {	}
+	if (!key) {
+		ListKey *lkTest = 0;
+		try {
+			lkTest = SWDYNAMIC_CAST(ListKey, this->key);
+		}
+		catch ( ... ) {	}
+		if (lkTest) {
+			try {
+				key = SWDYNAMIC_CAST(VerseKey, lkTest->GetElement());
+			}
+			catch ( ... ) {	}
+		}
+	}
+	if (!key) {
+		tmpVK = *(this->key);
+		return tmpVK;
+	}
+	else	return *key;
 }
+
+
+SWORD_NAMESPACE_END
