@@ -21,6 +21,9 @@
 #include <utilfuns.h>
 #include <rawstr.h>
 #include <sysdata.h>
+
+SWORD_NAMESPACE_START
+
 /******************************************************************************
  * RawStr Statics
  */
@@ -168,7 +171,7 @@ signed char RawStr::findoffset(const char *ikey, long *start, unsigned short *si
 		if (*ikey) {
 			headoff = 0;
 
-			key = new char [ strlen(ikey) + 10 ]; // just in case toupper needs a few extra
+			key = new char [ (strlen(ikey)*2) + 10 ]; // just in case toupper needs a few extra
 			strcpy(key, ikey);
 			toupperstr_utf8(key);
 
@@ -549,3 +552,5 @@ signed char RawStr::createModule(const char *ipath)
 	
 	return 0;
 }
+
+SWORD_NAMESPACE_END
