@@ -15,6 +15,8 @@
 #endif
 #include <ctype.h>
 
+SWORD_NAMESPACE_START
+
 const char GBFStrongs::on[] = "On";
 const char GBFStrongs::off[] = "Off";
 const char GBFStrongs::optName[] = "Strong's Numbers";
@@ -55,7 +57,7 @@ char GBFStrongs::ProcessText(char *text, int maxlen, const SWKey *key, const SWM
 	char *ch;
 	char *textStart = text, *textEnd = 0;
 	bool newText = false;
-	string tmp;
+	std::string tmp;
 
 	len = strlen(text) + 1;	// shift string to right of buffer
 	if (len < maxlen) {
@@ -128,3 +130,5 @@ char GBFStrongs::ProcessText(char *text, int maxlen, const SWKey *key, const SWM
 	*to = 0;
 	return 0;
 }
+
+SWORD_NAMESPACE_END
