@@ -10,6 +10,8 @@
 #include <latin1utf8.h>
 #include <swmodule.h>
 
+SWORD_NAMESPACE_START
+
 Latin1UTF8::Latin1UTF8() {
 }
 
@@ -21,8 +23,6 @@ char Latin1UTF8::ProcessText(char *text, int maxlen, const SWKey *key, const SWM
 	 if ((unsigned long)key < 2)	// hack, we're en(1)/de(0)ciphering
 		return -1;
         len = strlen(text) + 1;
-	if (len == maxlen + 1)
-        	maxlen = (maxlen + 1) * FILTERPAD;
         // shift string to right of buffer
 	if (len < maxlen) {
 	  memmove(&text[maxlen - len], text, len);
@@ -178,3 +178,5 @@ char Latin1UTF8::ProcessText(char *text, int maxlen, const SWKey *key, const SWM
 	*to = 0;
 	return 0;
 }
+
+SWORD_NAMESPACE_END
