@@ -4,7 +4,7 @@
  *  				many filters will need and can use as a starting
  *  				point. 
  *
- * $Id: swbasicfilter.cpp,v 1.18 2002/06/06 21:08:47 scribe Exp $
+ * $Id: swbasicfilter.cpp,v 1.20 2002/10/01 22:04:59 dglassey Exp $
  *
  * Copyright 2001 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -28,6 +28,8 @@
 #include <stdio.h>
 #include <stdarg.h>
 
+SWORD_NAMESPACE_START
+
 SWBasicFilter::SWBasicFilter() {
 	tokenStart = 0;
 	tokenEnd = 0;
@@ -203,7 +205,7 @@ char SWBasicFilter::ProcessText(char *text, int maxlen, const SWKey *key, const
 	char tokenEndLen   = strlen(tokenEnd);
 	char tokenStartPos = 0, tokenEndPos = 0;
 	DualStringMap userData;
-	string lastTextNode;
+	std::string lastTextNode;
 
 	bool suspendTextPassThru = false;
 	userData["suspendTextPassThru"] = "false";
@@ -297,4 +299,4 @@ char SWBasicFilter::ProcessText(char *text, int maxlen, const SWKey *key, const
 }
 
 
-
+SWORD_NAMESPACE_END
