@@ -16,6 +16,8 @@
 #endif
 #include <ctype.h>
 
+SWORD_NAMESPACE_START
+
 const char ThMLStrongs::on[] = "On";
 const char ThMLStrongs::off[] = "Off";
 const char ThMLStrongs::optName[] = "Strong's Numbers";
@@ -55,7 +57,7 @@ char ThMLStrongs::ProcessText(char *text, int maxlen, const SWKey *key, const SW
 	char *valto;
 	char *ch;
 	char *textStart = text, *textEnd = 0;
-	string tmp;
+	std::string tmp;
 	bool newText = false;
 
 	len = strlen(text) + 1;	// shift string to right of buffer
@@ -154,3 +156,5 @@ char ThMLStrongs::ProcessText(char *text, int maxlen, const SWKey *key, const SW
 	*to = 0;
 	return 0;
 }
+
+SWORD_NAMESPACE_END
