@@ -13,6 +13,8 @@
 #include <unixstr.h>
 #endif
 
+#include <unicode/ucnv.h>
+#include <unicode/uchar.h>
 #include <utf8transliterator.h>
 
 #ifndef _ICUSWORD_
@@ -20,6 +22,9 @@
 #endif
 #include <swlog.h>
 
+SWORD_NAMESPACE_START
+
+#if 0
 #ifdef _ICU_
 class UnicodeCaster {
 	const UnicodeString &ustr;
@@ -27,6 +32,7 @@ public:
 	UnicodeCaster(const UnicodeString &ustr):ustr(ustr) {}; operator const char *() { return ""; };
 };
 
+#endif
 #endif
 const char UTF8Transliterator::optionstring[NUMTARGETSCRIPTS][16] = {
         "Off",
@@ -160,7 +166,8 @@ void UTF8Transliterator::Load(UErrorCode &status)
 						   0x0046 /*F*/) ?
 						  UTRANS_FORWARD : UTRANS_REVERSE;
 					   //registry->put(id, resString, dir, visible);
-			    SWLog::systemlog->LogInformation("instantiating %s ...", (const char *)(UnicodeCaster)resString);
+			    //SWLog::systemlog->LogInformation("instantiating %s ...", (const char *)(UnicodeCaster)resString);
+				SWLog::systemlog->LogInformation("instantiating %s ...", resString.getBuffer());
 			    registerTrans(id, resString, dir, status);
 				SWLog::systemlog->LogInformation("done.");
 				    }
@@ -194,7 +201,8 @@ void  UTF8Transliterator::registerTrans(const UnicodeString& ID, const UnicodeSt
 		UTransDirection dir, UErrorCode &status )
 {
 #ifndef _ICUSWORD_
-		SWLog::systemlog->LogInformation("registering ID locally %s", (const char *)(UnicodeCaster)ID);
+		//SWLog::systemlog->LogInformation("registering ID locally %s", (const char *)(UnicodeCaster)ID);
+		SWLog::systemlog->LogInformation("registering ID locally %s", ID.getBuffer());
 		SWTransData swstuff; 
 		swstuff.resource = resource;
 		swstuff.dir = dir;
@@ -212,7 +220,8 @@ bool UTF8Transliterator::checkTrans(const UnicodeString& ID, UErrorCode &status
 		if (!U_FAILURE(status))
 		{
 			// already have it, clean up and return true
-			SWLog::systemlog->LogInformation("already have it %s", (const char *)(UnicodeCaster)ID);
+			//SWLog::systemlog->LogInformation("already have it %s", (const char *)(UnicodeCaster)ID);
+			SWLog::systemlog->LogInformation("already have it %s", ID.getBuffer());
 			delete trans;
 			return true;
 		}
@@ -227,7 +236,8 @@ bool UTF8Transliterator::checkTrans(const UnicodeString& ID, UErrorCode &status
 		//UErrorCode status;
 		//std::cout << "unregistering " << ID << std::endl;
 		//Transliterator::unregister(ID);
-		SWLog::systemlog->LogInformation("resource is %s", (const char *)(UnicodeCaster)swstuff.resource);
+		//SWLog::systemlog->LogInformation("resource is %s", (const char *)(UnicodeCaster)swstuff.resource);
+		SWLog::systemlog->LogInformation("resource is %s", swstuff.resource.getBuffer());
 		
 		// Get the rules
 		//std::cout << "importing: " << ID << ", " << resource << std::endl;
@@ -712,6 +722,8 @@ char UTF8Transliterator::ProcessText(char *text, int maxlen, const SWKey *key, c
         }
 	return 0;
 }
+
+SWORD_NAMESPACE_END
 #endif
 
 
