@@ -22,6 +22,8 @@
 #define O_BINARY 0
 #endif
 
+SWORD_NAMESPACE_START
+
 /******************************************************************************
  * RawGenBook Constructor - Initializes data for instance of RawGenBook
  *
@@ -115,7 +117,7 @@ char *RawGenBook::getRawEntry() {
           entryBuf[size] = 0;
 
 		rawFilter(entryBuf, size, 0);	// hack, decipher
-		rawFilter(entryBuf, size, key);
+		rawFilter(entryBuf, size*FILTERPAD, key);
 
 		   if (!isUnicode())
 			RawStr::preptext(entryBuf);
@@ -216,3 +218,5 @@ SWKey *RawGenBook::CreateKey() {
 	TreeKeyIdx *newKey = new TreeKeyIdx(path);
 	return newKey;
 }
+
+SWORD_NAMESPACE_END
