@@ -19,6 +19,7 @@
 #include <rawstr.h>
 #include <rawld.h>
 
+SWORD_NAMESPACE_START
 
  /******************************************************************************
  * RawLD Constructor - Initializes data for instance of RawLD
@@ -91,7 +92,7 @@ char RawLD::getEntry(long away)
 	if (!(retval = findoffset(buf, &start, &size, away))) {
 		readtext(start, &size, &idxbuf, &entrybuf);
 		rawFilter(entrybuf, size, 0);	// hack, decipher
-		rawFilter(entrybuf, size, key);
+		rawFilter(entrybuf, size*FILTERPAD, key);
 		entrySize = size;        // support getEntrySize call
 		if (!key->Persist())			// If we have our own key
 			*key = idxbuf;				// reset it to entry index buffer
@@ -173,3 +174,5 @@ void RawLD::linkEntry(const SWKey *inkey) {
 void RawLD::deleteEntry() {
 	settext(*key, "");
 }
+
+SWORD_NAMESPACE_END
