@@ -19,6 +19,7 @@
 #include <zstr.h>
 #include <zld.h>
 
+SWORD_NAMESPACE_START
 
  /******************************************************************************
  * RawLD Constructor - Initializes data for instance of RawLD
@@ -93,7 +94,7 @@ char zLD::getEntry(long away) {
 		entrybuf = new char [ size * FILTERPAD ];
 		strcpy(entrybuf, ebuf);
 
-		rawFilter(entrybuf, size, key);
+		rawFilter(entrybuf, size*FILTERPAD, key);
 
 		entrySize = size;        // support getEntrySize call
 		if (!key->Persist())			// If we have our own key
@@ -172,3 +173,5 @@ void zLD::linkEntry(const SWKey *inkey) {
 void zLD::deleteEntry() {
 	setText(*key, "");
 }
+
+SWORD_NAMESPACE_END
