@@ -13,7 +13,7 @@
 #include <unistd.h>
 #endif
 
-#include <string.h>
+#include <string>
 #include <utilfuns.h>
 #include <rawverse.h>
 #include <rawtext.h>
@@ -27,6 +27,12 @@
 #define O_BINARY 0
 #endif
 
+using std::string;
+using std::map;
+using std::list;
+
+SWORD_NAMESPACE_START
+
 /******************************************************************************
  * RawText Constructor - Initializes data for instance of RawText
  *
@@ -71,6 +77,35 @@ RawText::~RawText()
 }
 
 
+VerseKey &RawText::getVerseKey() {
+	static VerseKey tmpVK;
+	VerseKey *key;
+	// see if we have a VerseKey * or decendant
+	try {
+		key = SWDYNAMIC_CAST(VerseKey, this->key);
+	}
+	catch ( ... ) {	}
+	if (!key) {
+		ListKey *lkTest = 0;
+		try {
+			lkTest = SWDYNAMIC_CAST(ListKey, this->key);
+		}
+		catch ( ... ) {	}
+		if (lkTest) {
+			try {
+				key = SWDYNAMIC_CAST(VerseKey, lkTest->GetElement());
+			}
+			catch ( ... ) {	}
+		}
+	}
+	if (!key) {
+		tmpVK = *(this->key);
+		return tmpVK;
+	}
+	else	return *key;
+}
+
+
 /******************************************************************************
  * RawText::getRawEntry	- Returns the correct verse when char * cast
  *					is requested
@@ -81,18 +116,9 @@ RawText::~RawText()
 char *RawText::getRawEntry() {
 	long  start = 0;
 	unsigned short size = 0;
-	VerseKey *key = 0;
+	VerseKey &key = getVerseKey();
 
-	// see if we have a VerseKey * or decendant
-	try {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	catch ( ... ) {	}
-	// if we don't have a VerseKey * decendant, create our own
-	if (!key)
-		key = new VerseKey(this->key);
-
-	findoffset(key->Testament(), key->Index(), &start, &size);
+	findoffset(key.Testament(), key.Index(), &start, &size);
 	entrySize = size;        // support getEntrySize call
 
 	unsigned long newsize = (size + 2) * FILTERPAD;
@@ -104,18 +130,15 @@ char *RawText::getRawEntry() {
 	}
 	*entrybuf = 0;
 
-	readtext(key->Testament(), start, (size + 2), entrybuf);
+	readtext(key.Testament(), start, (size + 2), entrybuf);
      entrybuf[size] = 0;
 
 	rawFilter(entrybuf, size, 0);	// hack, decipher
-	rawFilter(entrybuf, size, key);
+	rawFilter(entrybuf, size*FILTERPAD, &key);
 
 	if (!isUnicode())
 		preptext(entrybuf);
 
-	if (this->key != key) // free our key if we created a VerseKey
-		delete key;
-
 	return entrybuf;
 }
 
@@ -452,34 +475,14 @@ ListKey &RawText::Search(const char *istr, int searchType, int flags, SWKey *sco
 
 
 void RawText::setEntry(const char *inbuf, long len) {
-	VerseKey *key = 0;
-	// see if we have a VerseKey * or decendant
-	try {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	catch ( ... ) {}
-	// if we don't have a VerseKey * decendant, create our own
-	if (!key)
-		key = new VerseKey(this->key);
-
-	settext(key->Testament(), key->Index(), inbuf, len);
-
-	if (this->key != key) // free our key if we created a VerseKey
-		delete key;
+	VerseKey &key = getVerseKey();
+	settext(key.Testament(), key.Index(), inbuf, len);
 }
 
 
 void RawText::linkEntry(const SWKey *inkey) {
-	VerseKey *destkey = 0;
+	VerseKey &destkey = getVerseKey();
 	const VerseKey *srckey = 0;
-	// see if we have a VerseKey * or decendant
-	try {
-		destkey = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	catch ( ... ) {}
-	// if we don't have a VerseKey * decendant, create our own
-	if (!destkey)
-		destkey = new VerseKey(this->key);
 
 	// see if we have a VerseKey * or decendant
 	try {
@@ -490,10 +493,7 @@ void RawText::linkEntry(const SWKey *inkey) {
 	if (!srckey)
 		srckey = new VerseKey(inkey);
 
-	linkentry(destkey->Testament(), destkey->Index(), srckey->Index());
-
-	if (this->key != destkey) // free our key if we created a VerseKey
-		delete destkey;
+	linkentry(destkey.Testament(), destkey.Index(), srckey->Index());
 
 	if (inkey != srckey) // free our key if we created a VerseKey
 		delete srckey;
@@ -507,20 +507,8 @@ void RawText::linkEntry(const SWKey *inkey) {
  */
 
 void RawText::deleteEntry() {
-
-	VerseKey *key = 0;
-
-	try {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	catch ( ... ) {}
-	if (!key)
-		key = new VerseKey(this->key);
-
-	settext(key->Testament(), key->Index(), "");
-
-	if (key != this->key)
-		delete key;
+	VerseKey &key = getVerseKey();
+	settext(key.Testament(), key.Index(), "");
 }
 
 /******************************************************************************
@@ -534,14 +522,7 @@ void RawText::deleteEntry() {
 void RawText::increment(int steps) {
 	long  start;
 	unsigned short size;
-	VerseKey *tmpkey = 0;
-
-	try {
-		tmpkey = SWDYNAMIC_CAST(VerseKey, key);
-	}
-	catch ( ... ) {}
-	if (!tmpkey)
-		tmpkey = new VerseKey(key);
+	VerseKey *tmpkey = &getVerseKey();
 
 	findoffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
 
@@ -551,15 +532,7 @@ void RawText::increment(int steps) {
 		unsigned short lastsize = size;
 		SWKey lasttry = *tmpkey;
 		(steps > 0) ? (*key)++ : (*key)--;
-		if (tmpkey != key)
-			delete tmpkey;
-		tmpkey = 0;
-		try {
-			tmpkey = SWDYNAMIC_CAST(VerseKey, key);
-		}
-		catch ( ... ) {}
-		if (!tmpkey)
-			tmpkey = new VerseKey(key);
+		tmpkey = &getVerseKey();
 
 		if ((error = key->Error())) {
 			*key = lastgood;
@@ -569,14 +542,14 @@ void RawText::increment(int steps) {
 		findoffset(tmpkey->Testament(), index, &start, &size);
 		if (
 			(((laststart != start) || (lastsize != size))	// we're a different entry
-				&& (start > 0) && (size))	// and we actually have a size
+//				&& (start > 0)
+				&& (size))	// and we actually have a size
 				||(!skipConsecutiveLinks)) {	// or we don't want to skip consecutive links
 			steps += (steps < 0) ? 1 : -1;
 			lastgood = *tmpkey;
 		}
 	}
 	error = (error) ? KEYERR_OUTOFBOUNDS : 0;
-
-	if (tmpkey != key)
-		delete tmpkey;
 }
+
+SWORD_NAMESPACE_END
