@@ -1,5 +1,8 @@
 #include <swmgr.h>
 #include <iostream>
+#ifndef NO_SWORD_NAMESPACE
+using namespace sword;
+#endif
 
 int main (int argc, char* argv[]) {
         SWMgr mgr;
