@@ -4,6 +4,9 @@
 
 #include <versekey.h>
 #include <localemgr.h>
+#ifndef NO_SWORD_NAMESPACE
+using namespace sword;
+#endif
 
 int main(int argc, char **argv) {
 	if ((argc != 2) && (argc != 3)) {
@@ -23,7 +26,7 @@ int main(int argc, char **argv) {
 	for (int i = 0; i < verses.Count(); i++) {
 		VerseKey *element = dynamic_cast<VerseKey *>(verses.GetElement(i));
 		if (element) {
-			std::cout << (string(element->LowerBound()) + " - " + string(element->UpperBound())).c_str() << "\n";
+			std::cout << (std::string(element->LowerBound()) + " - " + std::string(element->UpperBound())).c_str() << "\n";
 		}
 		else	std::cout << (const char *)*verses.GetElement(i) << "\n";
 //		else	{
