@@ -12,7 +12,9 @@
 #include <unistd.h>
 #endif
 
-
+#ifndef NO_SWORD_NAMESPACE
+using namespace sword;
+#endif
 
 int main(int argc, char **argv)
 {
@@ -29,7 +31,7 @@ int main(int argc, char **argv)
 	long maxoff = lseek(idxfd->getFd(), 0, SEEK_END) - 6;
 	FileMgr::systemFileMgr.close(idxfd);
 
-	string last = "";
+	std::string last = "";
 	bool first = true;
 	char *trybuf = 0;
 	for (long index = 0; index < maxoff; index+=6) {
