@@ -23,6 +23,13 @@
 #include <markupfiltmgr.h>
 #include <algorithm>
 
+#ifndef NO_SWORD_NAMESPACE
+using namespace sword;
+#endif
+using std::endl;
+using std::cerr;
+using std::cout;
+
 void errorOutHelp(char *appName) {
 	cerr << appName << " - a tool to output a Sword module in OSIS format\n";
 	cerr << "usage: "<< appName << " <modname> \n";
